@@ -23,6 +23,7 @@ from tencentcloud.tcb.v20180608 import models
 class TcbClient(AbstractClient):
     _apiVersion = '2018-06-08'
     _endpoint = 'tcb.tencentcloudapi.com'
+    _service = 'tcb'
 
 
     def CheckTcbService(self, request):
@@ -249,6 +250,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteCloudBaseProjectLatestVersion(self, request):
+        """删除云项目
+
+        :param request: Request instance for DeleteCloudBaseProjectLatestVersion.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.DeleteCloudBaseProjectLatestVersionRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.DeleteCloudBaseProjectLatestVersionResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteCloudBaseProjectLatestVersion", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteCloudBaseProjectLatestVersionResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteEndUser(self, request):
         """删除终端用户
 
@@ -361,6 +390,34 @@ class TcbClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCloudBaseRunResourceForExtend(self, request):
+        """查看容器托管的集群状态扩展使用
+
+        :param request: Request instance for DescribeCloudBaseRunResourceForExtend.
+        :type request: :class:`tencentcloud.tcb.v20180608.models.DescribeCloudBaseRunResourceForExtendRequest`
+        :rtype: :class:`tencentcloud.tcb.v20180608.models.DescribeCloudBaseRunResourceForExtendResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCloudBaseRunResourceForExtend", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCloudBaseRunResourceForExtendResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCloudBaseRunServerVersion(self, request):
         """查询服务版本的详情，CPU和MEM  请使用CPUSize和MemSize
 
